==> haskell-abstract-deque-0.3-2-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-3xNrV1OHLKZHwGiIECHG3h
key: abstract-deque-0.3-3xNrV1OHLKZHwGiIECHG3h
license: BSD3
maintainer: rrnewton@gmail.com
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
author: Ryan R. Newton
exposed: True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
    Data.Concurrent.Deque.Debugger
abi: c1c59acac1925ff71960b41ec7fc897f
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.0.1/site-local/abstract-deque-0.3
data-dir: /usr/share/arm-linux-ghc-8.0.1/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-3xNrV1OHLKZHwGiIECHG3h
depends:
    array-0.5.1.1 base-4.9.0.0 containers-0.5.7.1
    random-1.1-54KmMHXjttlERYcr1mvsAe time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-abstract-deque-0.3-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-abstract-deque.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: abstract-deque
version: 0.3
id: abstract-deque-0.3-2zsgznXQNzOK40bsGEQM3E
key: abstract-deque-0.3-2zsgznXQNzOK40bsGEQM3E
license: BSD3
maintainer: rrnewton@gmail.com
homepage: https://github.com/rrnewton/haskell-lockfree/wiki
synopsis: Abstract, parameterized interface to mutable Deques.
description:
    An abstract interface to highly-parameterizable queues/deques.
    .
    Background: There exists a feature space for queues that extends between:
    .
    * simple, single-ended, non-concurrent, bounded queues
    .
    * double-ended, threadsafe, growable queues
    .
    ... with important points inbetween (such as
    the queues used for work-stealing).
    .
    This package includes an interface for Deques that allows the
    programmer to use a single API for all of the above, while using the
    type-system to select an efficient implementation given the
    requirements (using type families).
    .
    This package also includes a simple reference implementation based
    on '\''IORef'\'' and "Data.Sequence".
category: Data
author: Ryan R. Newton
exposed: True
exposed-modules:
    Data.Concurrent.Deque.Class Data.Concurrent.Deque.Reference
    Data.Concurrent.Deque.Reference.DequeInstance
    Data.Concurrent.Deque.Debugger
abi: 1162d9d23502075846af29fcd6ce3992
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/abstract-deque-0.3
library-dirs: /usr/lib/ghc-8.0.2/site-local/abstract-deque-0.3
dynamic-library-dirs: /usr/lib/arm-linux-ghc-8.0.2
data-dir: /usr/share/arm-linux-ghc-8.0.2/abstract-deque-0.3
hs-libraries: HSabstract-deque-0.3-2zsgznXQNzOK40bsGEQM3E
depends:
    array-0.5.1.1 base-4.9.1.0 containers-0.5.7.1
    random-1.1-9tceXaeYIMZ4JrKq20Egog time-1.6.0.1
haddock-interfaces: /usr/share/doc/haskell-abstract-deque/html/abstract-deque.haddock
haddock-html: /usr/share/doc/haskell-abstract-deque/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
